==> postcss-flexbox-1.0.1.tgz: package/flexbox-configs.js <==
module.exports = {
  'box': [
    'display: flex',
    'display: -moz-box',
    'display: -ms-flexbox',
    'display: -webkit-flex'
  ],

  'horizontal' : [
    'flex-direction: row',
    '-webkit-flex-direction: row',
    '-ms-flex-direction: row',
    '-moz-flex-direction: row'
  ],

  'vertical': [
    'flex-direction: column',
    '-webkit-flex-direction: column',
    '-ms-flex-direction: column',
    '-moz-flex-direction: column',
  ],

  'horizontal-reverse': [
    '-ms-flex-direction: row-reverse',
    '-webkit-flex-direction: row-reverse',
    'flex-direction: row-reverse'
  ],

  'vertical-reverse': [
    '-ms-flex-direction: column-reverse',
    '-webkit-flex-direction: column-reverse',
    'flex-direction: column-reverse'
  ],

  'horizontal-bottom': [
    '-ms-flex-align: end',
    '-webkit-align-items: flex-end',
    'align-items: flex-end'
  ],

  'horizontal-top': [
    '-ms-flex-align: start',
    '-webkit-align-items: flex-start',
    'align-items: flex-start'
  ],

  'horizontal-middle': [
    '-ms-flex-align: center',
    '-webkit-align-items: center',
    'align-items: center'
  ],

  'horizontal-right': [
    '-ms-flex-pack: end',
    '-webkit-justify-content: flex-end',
    'justify-content: flex-end'
  ],

  'horizontal-left': [
    '-ms-flex-pack: start',
    '-webkit-justify-content: flex-start',
    'justify-content: flex-start'
  ],

  'horizontal-center': [
    '-ms-flex-pack: center',
    '-webkit-justify-content: center',
    'justify-content: center'
  ],

  'space-around': [
    '-ms-flex-pack: around',
    '-webkit-justify-content: space-around',
    'justify-content: space-around'
  ],

  'space-between': [
    '-ms-flex-pack: justify',
    '-webkit-justify-content: space-between',
    'justify-content: space-between'
  ],

  'vertical-right': [
    '-ms-flex-align: end',
    '-webkit-align-items: flex-end',
    'align-items: flex-end'
  ],

  'vertical-left': [
    '-ms-flex-align: start',
    '-webkit-align-items: flex-start',
    'align-items: flex-start'
  ],

  'vertical-center': [
    '-ms-flex-align: center',
    '-webkit-align-items: center',
    'align-items: center'
  ],

  'vertical-top': [
    '-ms-flex-pack: start',
    '-webkit-justify-content: flex-start',
    'justify-content: flex-start'
  ],

  'vertical-middle': [
    '-ms-flex-pack: center',
    '-webkit-justify-content: center',
    'justify-content: center'
  ],

  'vertical-bottom': [
    '-ms-flex-pack: end',
    '-webkit-justify-content: flex-end',
    'justify-content: flex-end'
  ],

  'self-bottom': [
    '-ms-align-self: flex-end',
    '-webkit-align-self: flex-end',
    'align-self: flex-end'
  ],

  'self-right': [
    '-ms-align-self: flex-end',
    '-webkit-align-self: flex-end',
    'align-self: flex-end'
  ],

  'self-top': [
    '-ms-align-self: flex-start',
    '-webkit-align-self: flex-start',
    'align-self: flex-start'
  ],
  'self-left': [
    '-ms-align-self: flex-start',
    '-webkit-align-self: flex-start',
    'align-self: flex-start'
  ],

  'self-middle': [
    '-ms-align-self: center',
    '-webkit-align-self: center',
    'align-self: center'
  ],

  'self-center': [
    '-ms-align-self: center',
    '-webkit-align-self: center',
    'align-self: center'
  ],

  'self-stretch': [
    '-ms-align-self: stretch',
    '-webkit-align-self: stretch',
    'align-self: stretch'
  ],

  'wrap': [
    '-ms-flex-wrap: wrap',
    '-webkit-flex-wrap: wrap',
    'flex-wrap: wrap'
  ],

  'wrap-reverse': [
    '-ms-flex-wrap: wrap-reverse',
    '-webkit-flex-wrap: wrap-reverse',
    'flex-wrap: wrap-reverse'
  ],

  'flex-auto': [
    '-ms-flex: 1 1 auto',
    '-webkit-flex: 1 1 auto',
    'flex: 1 1 auto'
  ],

  'flex-none': [
    '-ms-flex: none',
    '-webkit-flex: none',
    'flex: none'
  ],

  'flex-1': [
    '-ms-flex: 1',
    '-webkit-flex: 1',
    'flex: 1'
  ],

  'flex-2': [
    '-ms-flex: 2',
    '-webkit-flex: 2',
    'flex: 2'
  ],

  'flex-3': [
    '-ms-flex: 3',
    '-webkit-flex: 3',
    'flex: 3'
  ],

  'flex-4': [
    '-ms-flex: 4',
    '-webkit-flex: 4',
    'flex: 4'
  ],

  'flex-5': [
    '-ms-flex: 5',
    '-webkit-flex: 5',
    'flex: 5'
  ],

  'flex-6': [
    '-ms-flex: 6',
    '-webkit-flex: 6',
    'flex: 6'
  ],

  'flex-7': [
    '-ms-flex: 7',
    '-webkit-flex: 7',
    'flex: 7'
  ],

  'flex-8': [
    '-ms-flex: 8',
    '-webkit-flex: 8',
    'flex: 8'
  ],

  'flex-9': [
    '-ms-flex: 9',
    '-webkit-flex: 9',
    'flex: 9'
  ],

  'flex-10': [
    '-ms-flex: 10',
    '-webkit-flex: 10',
    'flex: 10'
  ],

  'flex-11': [
    '-ms-flex: 11',
    '-webkit-flex: 11',
    'flex: 11'
  ],

  'flex-12': [
    '-ms-flex: 12',
    '-webkit-flex: 12',
    'flex: 12'
  ],

  'direction-specific-values' : [
    'reverse', 'top', 'bottom', 'middle', 'right', 'left', 'center'
  ],
};

==> postcss-flexbox-1.0.2.tgz: package/flexbox-configs.js <==
module.exports = {
  'box': [
    'display: flex'
  ],

  'horizontal' : [
    'flex-direction: row'
  ],

  'vertical': [
    'flex-direction: column'
  ],

  'horizontal-reverse': [
    'flex-direction: row-reverse'
  ],

  'vertical-reverse': [
    'flex-direction: column-reverse'
  ],

  'horizontal-bottom': [
    'align-items: flex-end'
  ],

  'horizontal-top': [
    'align-items: flex-start'
  ],

  'horizontal-middle': [
    'align-items: center'
  ],

  'horizontal-right': [
    'justify-content: flex-end'
  ],

  'horizontal-left': [
    'justify-content: flex-start'
  ],

  'horizontal-center': [
    'justify-content: center'
  ],

  'space-around': [
    'justify-content: space-around'
  ],

  'space-between': [
    'justify-content: space-between'
  ],

  'vertical-right': [
    'align-items: flex-end'
  ],

  'vertical-left': [
    'align-items: flex-start'
  ],

  'vertical-center': [
    'align-items: center'
  ],

  'vertical-top': [
    'justify-content: flex-start'
  ],

  'vertical-middle': [
    'justify-content: center'
  ],

  'vertical-bottom': [
    'justify-content: flex-end'
  ],

  'self-bottom': [
    'align-self: flex-end'
  ],

  'self-right': [
    'align-self: flex-end'
  ],

  'self-top': [
    'align-self: flex-start'
  ],

  'self-left': [
    'align-self: flex-start'
  ],

  'self-middle': [
    'align-self: center'
  ],

  'self-center': [
    'align-self: center'
  ],

  'self-stretch': [
    'align-self: stretch'
  ],

  'wrap': [
    'flex-wrap: wrap'
  ],

  'wrap-reverse': [
    'flex-wrap: wrap-reverse'
  ],

  'flex-auto': [
    'flex: 1 1 auto'
  ],

  'flex-none': [
    'flex: none'
  ],

  'flex-1': [
    'flex: 1'
  ],

  'flex-2': [
    'flex: 2'
  ],

  'flex-3': [
    'flex: 3'
  ],

  'flex-4': [
    'flex: 4'
  ],

  'flex-5': [
    'flex: 5'
  ],

  'flex-6': [
    'flex: 6'
  ],

  'flex-7': [
    'flex: 7'
  ],

  'flex-8': [
    'flex: 8'
  ],

  'flex-9': [
    'flex: 9'
  ],

  'flex-10': [
    'flex: 10'
  ],

  'flex-11': [
    'flex: 11'
  ],

  'flex-12': [
    'flex: 12'
  ],

  'direction-specific-values' : [
    'reverse', 'top', 'bottom', 'middle', 'right', 'left', 'center'
  ],
};
